@@ -16,35 +16,6 @@ Ouputs treatments, clustered such that things that have similar
 results get the same ranks.
 """
 
-
-# -----------------------------------------------------
-# Examples
-
-def skDemo(n=5):
-    # Rx.data is one way to run the code
-    return Rx.data(x1=[0.34, 0.49, 0.51, 0.6] * n,
-                   x2=[0.6, 0.7, 0.8, 0.89] * n,
-                   x3=[0.13, 0.23, 0.38, 0.38] * n,
-                   x4=[0.6, 0.7, 0.8, 0.9] * n,
-                   x5=[0.1, 0.2, 0.3, 0.4] * n)
-
-
-"""
-Another is to make a file
-
-x1  0.34  0.49  0.51  0.6
-x2  0.6   0.7   0.8   0.9
-x3  0.15  0.25  0.4   0.35
-x4  0.6   0.7   0.8   0.9
-x5  0.1   0.2   0.3   0.4
-
-Then call 
-
-   Rx.fileIn( fileName )
-
-"""
-
-
 # -----------------------------------------------------
 # Config
 
@@ -56,14 +27,14 @@ class THE:
     cliffs = o(dull=[0.147,  # small
                      0.33,  # medium
                      0.474  # large
-                     ][0])
+                     ])
     bs = o(conf=0.05,
            b=500)
     mine = o(private="_")
     char = o(skip="?")
     rx = o(show="%4s %10s %s")
     tile = o(width=50,
-             chops=[0.1, 0.3, 0.5, 0.7, 0.9],
+             chops=[0.1, 0.25, 0.5, 0.75, 0.9],
              marks=[" ", "-", "-", "-", " "],
              bar="|",
              star="*",
@@ -71,7 +42,7 @@ class THE:
 
 
 # -----------------------------------------------------
-def cliffsDelta(lst1, lst2, dull=THE.cliffs.dull):
+def cliffsDelta(lst1, lst2, dull=THE.cliffs.dull[0]):
     "By pre-soring the lists, this cliffsDelta runs in NlogN time"
 
     def runs(lst):
@@ -249,8 +220,16 @@ class Rx(Mine):
             print(THE.rx.show % (rx.rank, rx.rx, rx.tiles()))
 
     @staticmethod
-    def sk(rxs):
+    def sk(rxs, effect=THE.cliffs.dull[0]):
         "sort treatments and rank them"
+        effect_dict = {
+            'small': THE.cliffs.dull[0],
+            'medium': THE.cliffs.dull[1],
+            'large': THE.cliffs.dull[2]
+        }
+
+        if effect in effect_dict:
+            effect = effect_dict[effect]
 
         def divide(lo, hi, b4, rank):
             cut = left = right = None
@@ -343,27 +322,5 @@ def thing(x):
             return x
 
 
-# -------------------------------------------------------
-def _cliffsDelta():
-    "demo function"
-    lst1 = [1, 2, 3, 4, 5, 6, 7] * 100
-    n = 1
-    for _ in range(10):
-        lst2 = [x * n for x in lst1]
-        print(cliffsDelta(lst1, lst2), n)  # should return False
-        n *= 1.03
-
-
-def bsTest(n=1000, mu1=10, sigma1=1, mu2=10.2, sigma2=1):
-    def g(mu, sigma): return random.gauss(mu, sigma)
-
-    x = [g(mu1, sigma1) for i in range(n)]
-    y = [g(mu2, sigma2) for i in range(n)]
-    return n, mu1, sigma1, mu2, sigma2, \
-        'same' if bootstrap(x, y) else 'different'
-
-
-# -------------------------------------------------------
-
 if __name__ == "__main__":
     Rx.fileIn(sys.argv[1])
