@@ -6,7 +6,7 @@ from tensorflow.keras.utils import to_categorical
 import numpy as np
 import pandas as pd
 from raise_utils.learners.learner import Learner
-from raise_utils.transform.wfo import fuzz_data
+from raise_utils.transforms.wfo import fuzz_data
 from imblearn.over_sampling import SMOTE
 
 
@@ -75,7 +75,7 @@ class MulticlassDL(Learner):
         if self.wfo:
             self.x_train, self.y_train = fuzz_data(self.x_train, self.y_train)
             sm = SMOTE()
-            self.x_train, self.y_train = sm.fit_sample(
+            self.x_train, self.y_train = sm.fit_resample(
                 self.x_train, self.y_train)
 
             self.y_train = to_categorical(
